package com.example.data_push.service.impl;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.api.R;
import com.example.data_push.config.ZybConfig;
import com.example.data_push.dto.DataDto;
import com.example.data_push.service.PushDataService;
import com.example.data_push.util.JsonToXml2;
import com.example.data_push.vo.ZybVo;
import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringEscapeUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

/**
 * @Author: wl
 * @Date: 2023/3/24
 * @Description:
 */
@Slf4j
@Service
public class PushDataServiceImpl implements PushDataService {


    @Autowired
    private ZybConfig zybConfig;



    @Override
    public R pushData(DataDto dto) throws Exception {
        if (StringUtils.isEmpty(dto.getDataJson())){
            return R.failed("无法获取到推送数据");
        }
        log.info("获取原始数据成功,原始数据为："+dto.getDataJson());
        String result = HttpUtil.post(zybConfig.getUrl(), dto.getDataJson());
        log.info("调用省直平台成功，转义前:" + result);
        result = StringEscapeUtils.unescapeXml(result);
        log.info("转义后:" + result);
        if (!result.contains("<data>")){
            return  R.failed("调用省直平台推送失败");
        }
        String substring = result.substring(result.indexOf("<data>"), result.indexOf("</data>") + 7);
        //获取data数据
        JSONObject jsonObject = JsonToXml2.xmltoJson(substring).getJSONObject("data");
        log.info("获取data数据:" + new Gson().toJson(jsonObject));
        ZybVo zybVo = JSON.toJavaObject(jsonObject, ZybVo.class);
        log.info("实体类转换后:" + new Gson().toJson(zybVo));
        if ("-1".equals(zybVo.getReturnCode())) {
            return R.failed(zybVo.getMessage() + "," + zybVo.getErrorList().getError().getMessage());
        }
        log.info("单位申报成功");
        return R.ok(zybVo);
    }





}
